- unit verb – the finite verb of a clause, linked either to its subordinating word in subordinate epxressions, or to the reserved node value
root. for independent clauses.
- subordinating conjunction – a subordinating word, linked to the verb of the governing clause.
- relative pronoun – a relative pronoun, linked both to its antecedent and to its function in the relative clause.
- subject – a substantive linked to the verb of its verbal expression.
- direct object – a substantive linked to its transitive-active verbal expression.
- predicate – a substantive linked to a linking verb.
- agent – the head of a prepositional phrase expressing agent with a/ab, linked to a passive verb.
- auxiliary – a participle linked to a form of sum in compound forms of the perfect-passive/future-active systems.
- object of preposition – a substantive linked to its governing preposition.
- adverbial – an adverb, or a prepositional phrase used adverbially, linked to the verb it modifies.
- attributive – a prepositional phrase linking to the noun it modifies.
- adjectival – an adjective (or gerundive) linking to the noun it agrees with.
- genitive – a genitive substantive linked to the noun or verb it modifies.
- dative – a dative substantive linked to the noun or verb it relates to.
- ablative – an ablative substantive linked to the noun or verb it relates to.
- accusative – an accusative substantive that is not the special case of a direct object, linked to the verb or noun it relates to.
- vocative – a vocative substantive, linked to the verb of the clause it appears in.
- direct quote – verbal expression of directly quoted speech, linked to the verb introducing the direct speech.
- aside – verb of a a parenthetical aside, linked to the verb of the clause it interrupts.
- indirect statement – an infinitive in indirect-statement, linked to the governing verb.
- circumstantial participle – a participle linked to the substantive it agrees with.
- ablative absolute – an ablative substantive syntactically absolute from the verbal expression where it appears, linked to the verb of the verbal expression.
- coordinating conjunction – a coordinating conjunction, linked to the two items (nouns, adjectives, prepositional phrases, or verbal expressions) it joins.
- apposition – a subtantive in apposition, linked to the subtantive it stands in apposition to.
- complementary infinitive – an infinitive completing a governing verb like volo/incipio/audeo/licet/decet, linked to that verb.
- praenomen – an abbreviated Roman first-name token, linked to the associated
nomen or cognomen.